@@ -20,7 +20,7 @@ from dkist_processing_common.models.tags import Tag
 from dkist_processing_test.tasks.fail import FailTask
 from dkist_processing_test.tasks.fake_science import GenerateCalibratedData
 from dkist_processing_test.tasks.movie import AssembleTestMovie
-from dkist_processing_test.tasks.movie import MakeMovieFrames
+from dkist_processing_test.tasks.movie import MakeTestMovieFrames
 from dkist_processing_test.tasks.noop import NoOpTask
 from dkist_processing_test.tasks.write_l1 import WriteL1Data
 from dkist_processing_test.tests.conftest import generate_214_l0_fits_frame
@@ -148,7 +148,7 @@ def calibrated_header():
     hdu.header["PAC__006"] = "clear"
     hdu.header["PAC__007"] = "0"
     hdu.header["PAC__008"] = "FieldStop (2.8arcmin)"
-    hdu.header["INSTRUME"] = "VISP"
+    hdu.header["INSTRUME"] = "VBI"
     hdu.header["LINEWAV"] = 1080.0
     hdu.header["DATE-BGN"] = "2020-03-13T00:00:00.000"
     hdu.header["DATE-END"] = "2021-08-15T00:00:00.000"
@@ -312,7 +312,7 @@ def test_write_l1_task(write_l1_task, mocker):
 
 @pytest.fixture()
 def make_movie_frames_task(tmp_path, recipe_run_id):
-    with MakeMovieFrames(
+    with MakeTestMovieFrames(
         recipe_run_id=recipe_run_id, workflow_name="MakeMovieFrames", workflow_version="VX.Y"
     ) as task:
         task._scratch = WorkflowFileSystem(scratch_base_path=tmp_path)
